-- multitouch
-- License CC0 (Creative Commons license) (c) darkfrei, 2022


local Screen = {}

local white = {1,1,1}
local red = {1,0,0}
local green = {0,1,0}
local blue = {0,0,1}

function Screen:load()
	local width, heigh = love.graphics.getDimensions()
	self.width, self.heigh = width, heigh
--	if width >= heigh then
		self.x, self.y, self.w, self.h = love.window.getSafeArea()
--	else
--		self.y, self.x, self.h, self.w = love.window.getSafeArea()
--	end
	self.translate={x=0, y=0}
	self.scale=1
	self.touches = {}
	self.circle = {x=0, y=0, r=20, color = red}
end

function Screen:draw()
	love.graphics.setColor(0,1,0)
	love.graphics.setLineWidth(2)
	love.graphics.rectangle('line', self.x, self.y, self.w, self.h)
	
	love.graphics.setLineWidth(1)
	love.graphics.setColor(self.circle.color)
	love.graphics.circle ('line', self.circle.x, self.circle.y, self.circle.r)
	
	love.graphics.translate(math.floor(self.translate.x+0.5), math.floor(self.translate.y))
	love.graphics.scale(self.scale)
	
	
end


function Screen:updateCircle ()
	if #self.touches == 0 then
		self.circle.r = 20
		self.circle.color = red
	elseif #self.touches == 1 then
		self.circle.x = self.touches[1].x
		self.circle.y = self.touches[1].y
		self.circle.r = 40
		self.circle.color = white
	elseif #self.touches == 2 then
		self.circle.x = (self.touches[1].x + self.touches[2].x)/2
		self.circle.y = (self.touches[1].y + self.touches[2].y)/2
		self.circle.r = ((self.touches[2].x-self.touches[1].x)^2+(self.touches[2].y-self.touches[1].y)^2)^0.5/2
		self.circle.color = green
	else
		local x, y, n = 0, 0, #self.touches
		for i, touch in ipairs (self.touches) do
			x = x+touch.x
			y = y+touch.y
		end
		x, y = x/n, y/n -- circle center
		local r = 0
		for i, touch in ipairs (self.touches) do
			local dist = ((x-touch.x)^2+(y-touch.y)^2)^0.5
			r = r + dist
		end
		r = r/n
		self.circle.x = x
		self.circle.y = y
		self.circle.r = r
		self.circle.color = blue
	end
end


function Screen:touchpressed (id, x, y, dx, dy, pressure)
	local newTouch = {id=id, x=x, y=y, dx=0, dy=0}
	table.insert (self.touches, newTouch)
	Screen:updateCircle ()
end

-- https://love2d.org/wiki/love.touchmoved
function Screen:touchmoved (id, x, y, dx, dy, pressure)
	
--	local dpiScale = love.window.getDPIScale( ) -- 1.875
--	if #self.touches == 1 then
--		-- translate
--		self.translate.x = self.translate.x + dx
--		self.translate.y = self.translate.y + dy
--		self.touches[1].x = x
--		self.touches[1].y = y
--	elseif #self.touches == 2 then

		
--		local index = self.touches[1].id == id and 1 or 2
--		self.touches[index].x = x
--		self.touches[index].y = y
--		self.touches[index].dx = dx
--		self.touches[index].dy = dy

--		local x1, y1 = self.touches[1].x, self.touches[1].y
--		local x2, y2 = self.touches[2].x, self.touches[2].y
		
--		local dx1, dy1, dx2, dy2 = x2-x1, y2-y1
--		if index == 1 then
--			dx2, dy2 = x2-x1-dx, y2-y1-dy
--		else
--			dx2, dy2 = x2-x1+dx, y2-y1+dy
--		end
		
--		local mx, my=(x1+x2)/2, (y1+y2)/2
--		local dscale = (dx2*dx2+dy2*dy2)^0.5/(dx1*dx1+dy1*dy1)^0.5
--		Screen:zoomToPoint (mx, my, dscale)
		
----		self.translate.x = self.translate.x + (dx2-dx1)
----		self.translate.y = self.translate.y + (dy2-dy1)
--	end
	for i, touch in ipairs (self.touches) do
		if touch.id == id then
			touch.x = x
			touch.y = y
			touch.dx = dx
			touch.dy = dy
		end
	end
	Screen:updateCircle ()
end

-- https://love2d.org/wiki/love.touchreleased
function Screen:touchreleased (id, x, y, dx, dy, pressure)
	for i, touch in ipairs (self.touches) do
		if touch.id == id then
			table.remove (self.touches, i)
		end
	end
	Screen:updateCircle ()
end

return Screen